about summary refs log tree commit diff
path: root/src/test/compile-fail/kindck-send-object.rs
diff options
context:
space:
mode:
authorNick Cameron <ncameron@mozilla.com>2015-01-07 11:33:42 +1300
committerNick Cameron <ncameron@mozilla.com>2015-01-07 12:10:31 +1300
commit9f07d055f7823ac0e17e014f3effa2a0be0947e9 (patch)
treeb4a0f390cd26323522cbcfaf7ba2464fc5f13bb2 /src/test/compile-fail/kindck-send-object.rs
parent91ba66fa99830d4963d6adb47439b86253bf5a4c (diff)
downloadrust-9f07d055f7823ac0e17e014f3effa2a0be0947e9.tar.gz
rust-9f07d055f7823ac0e17e014f3effa2a0be0947e9.zip
markers -> marker
Diffstat (limited to 'src/test/compile-fail/kindck-send-object.rs')
-rw-r--r--src/test/compile-fail/kindck-send-object.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/test/compile-fail/kindck-send-object.rs b/src/test/compile-fail/kindck-send-object.rs
index 1235a0a1228..7984b3b32c2 100644
--- a/src/test/compile-fail/kindck-send-object.rs
+++ b/src/test/compile-fail/kindck-send-object.rs
@@ -20,11 +20,11 @@ trait Message : Send { }
 
 fn object_ref_with_static_bound_not_ok() {
     assert_send::<&'static (Dummy+'static)>();
     //~^ ERROR the trait `core::markers::Send` is not implemented
 }
 
 fn box_object_with_no_bound_not_ok<'a>() {
-    assert_send::<Box<Dummy>>(); //~ ERROR the trait `core::markers::Send` is not implemented
+    assert_send::<Box<Dummy>>(); //~ ERROR the trait `core::marker::Send` is not implemented
 }
 
 fn object_with_send_bound_ok() {
@@ -20,11 +20,11 @@ trait Message : Send { }
 fn object_ref_with_static_bound_not_ok() {
     assert_send::<&'static (Dummy+'static)>();
-    //~^ ERROR the trait `core::markers::Send` is not implemented
+    //~^ ERROR the trait `core::marker::Send` is not implemented
 }
 